@@ -1,4 +1,6 @@
 //! Common code used in hRPC code generation.
+#![deny(missing_docs)]
+
 use std::{
     error::Error as StdError,
     fmt::{self, Display, Formatter},
@@ -38,9 +40,7 @@ pub mod server;
 /// Body utitilies and types.
 pub mod body;
 /// The hRPC generated protocol.
-pub mod proto {
-    crate::include_proto!("hrpc.v1");
-}
+pub mod proto;
 
 /// Alias for a type-erased error type.
 pub type BoxError = Box<dyn std::error::Error + Send + Sync>;
