@@ -1,40 +1,43 @@
-use std::{convert::Infallible, future, net::ToSocketAddrs};
+use std::{convert::Infallible, future};
 
-use futures_util::future::BoxFuture;
 use tower::{Layer, Service as TowerService};
 
 use crate::{HttpRequest, HttpResponse};
-use handler::Handler;
 use router::Routes;
+use service::HrpcService;
 
 use self::router::RoutesFinalized;
 
 /// Error types used by hRPC.
 pub mod error;
-/// Handler type and handlers used by hRPC.
-pub mod handler;
 /// The router used by hRPC.
 pub mod router;
+/// Handler type and handlers used by hRPC.
+pub mod service;
 /// Socket used by hRPC for "streaming" RPCs.
 pub mod socket;
+/// Transports for hRPC services.
+///
+/// The only available transport (for now) is [`Hyper`].
+pub mod transport;
 /// Other useful types, traits and functions used by hRPC.
 pub mod utils;
 
 mod macros;
 pub(crate) mod ws;
 
-pub use handler::HrpcLayer;
+pub use service::HrpcLayer;
 
 // Prelude used by generated code. It is not meant to be used by users.
 #[doc(hidden)]
 pub mod gen_prelude {
     pub use super::{
         error::ServerResult,
-        handler::{unary_handler, ws_handler, Handler, HrpcLayer},
         router::Routes,
+        service::{unary_handler, ws_handler, HrpcLayer, HrpcService},
         socket::Socket,
-        utils::serve,
-        Service,
+        transport::{Hyper, Transport},
+        MakeRoutes,
     };
     pub use crate::{
         body::box_body, BoxError, HttpRequest, HttpResponse, Request as HrpcRequest,
@@ -44,7 +47,7 @@ pub mod gen_prelude {
     pub use futures_util::future::BoxFuture;
     pub use http::Response as _HttpResponse;
     pub use http_body::Body as HttpBody;
-    pub use std::{convert::Infallible, future::Future, sync::Arc};
+    pub use std::{convert::Infallible, future::Future, net::ToSocketAddrs, sync::Arc};
     pub use tower::{layer::util::Identity, Layer, Service as TowerService};
 }
 
@@ -52,25 +55,28 @@ pub mod gen_prelude {
 pub mod prelude {
     pub use super::{
         error::{CustomError, ServerResult},
-        handler::HrpcLayer,
+        service::HrpcLayer,
         socket::Socket,
-        Service,
+        transport::{Hyper, Transport},
+        MakeRoutes,
     };
-    pub use crate::{make_handler, IntoResponse, Request, Response};
+    pub use crate::{make_handler, proto::Error as HrpcError, IntoResponse, Request, Response};
     pub use hrpc_proc_macro::handler;
     pub use http::StatusCode;
 }
 
 /// The core trait of `hrpc-rs` servers. This trait acts as a `tower::MakeService`,
-/// it can produce a set of [`Routes`] and can be combined with other [`Service`]s.
-pub trait Service: Send + 'static {
+/// it can produce a set of [`Routes`] and can be combined with other [`MakeRoutes`]s.
+///
+/// Not to be confused with [`tower::Service`].
+pub trait MakeRoutes: Send + 'static {
     /// Creates a [`Routes`], which will be used to build a [`RoutesFinalized`] instance.
     fn make_routes(&self) -> Routes;
 
     /// Combines this server with another server.
     fn combine_with<Other>(self, other: Other) -> ServiceStack<Other, Self>
     where
-        Other: Service,
+        Other: MakeRoutes,
         Self: Sized,
     {
         ServiceStack {
@@ -94,28 +100,18 @@ pub trait Service: Send + 'static {
     /// [`HrpcLayer::new`].
     fn layer<L>(self, layer: L) -> LayeredService<L, Self>
     where
-        L: Layer<Handler, Service = Handler> + Clone + Sync + Send + 'static,
+        L: Layer<HrpcService, Service = HrpcService> + Clone + Sync + Send + 'static,
         Self: Sized,
     {
         LayeredService { inner: self, layer }
     }
-
-    /// Serves this service. See [`utils::serve`] for more information.
-    fn serve<'a, A>(self, address: A) -> BoxFuture<'a, Result<(), hyper::Error>>
-    where
-        A: ToSocketAddrs + Send + 'a,
-        A::Iter: Send,
-        Self: Sized,
-    {
-        Box::pin(utils::serve(self, address))
-    }
 }
 
-/// Type that layers the handlers that are produced by a [`Service`].
+/// Type that layers the handlers that are produced by a [`MakeRoutes`].
 pub struct LayeredService<L, S>
 where
-    L: Layer<Handler, Service = Handler> + Clone + Sync + Send + 'static,
-    S: Service,
+    L: Layer<HrpcService, Service = HrpcService> + Clone + Sync + Send + 'static,
+    S: MakeRoutes,
 {
     inner: S,
     layer: L,
@@ -123,8 +119,8 @@ where
 
 impl<L, S> Clone for LayeredService<L, S>
 where
-    L: Layer<Handler, Service = Handler> + Clone + Sync + Send + 'static,
-    S: Service + Clone,
+    L: Layer<HrpcService, Service = HrpcService> + Clone + Sync + Send + 'static,
+    S: MakeRoutes + Clone,
 {
     fn clone(&self) -> Self {
         Self {
@@ -134,22 +130,22 @@ where
     }
 }
 
-impl<L, S> Service for LayeredService<L, S>
+impl<L, S> MakeRoutes for LayeredService<L, S>
 where
-    L: Layer<Handler, Service = Handler> + Clone + Sync + Send + 'static,
-    S: Service,
+    L: Layer<HrpcService, Service = HrpcService> + Clone + Sync + Send + 'static,
+    S: MakeRoutes,
 {
     fn make_routes(&self) -> Routes {
-        let rb = Service::make_routes(&self.inner);
+        let rb = MakeRoutes::make_routes(&self.inner);
         rb.layer_all(self.layer.clone())
     }
 }
 
-/// Type that contains two [`Service`]s and stacks (combines) them.
+/// Type that contains two [`MakeRoutes`]s and stacks (combines) them.
 pub struct ServiceStack<Outer, Inner>
 where
-    Outer: Service,
-    Inner: Service,
+    Outer: MakeRoutes,
+    Inner: MakeRoutes,
 {
     outer: Outer,
     inner: Inner,
@@ -157,8 +153,8 @@ where
 
 impl<Outer, Inner> Clone for ServiceStack<Outer, Inner>
 where
-    Outer: Service + Clone,
-    Inner: Service + Clone,
+    Outer: MakeRoutes + Clone,
+    Inner: MakeRoutes + Clone,
 {
     fn clone(&self) -> Self {
         Self {
@@ -168,25 +164,25 @@ where
     }
 }
 
-impl<Outer, Inner> Service for ServiceStack<Outer, Inner>
+impl<Outer, Inner> MakeRoutes for ServiceStack<Outer, Inner>
 where
-    Outer: Service,
-    Inner: Service,
+    Outer: MakeRoutes,
+    Inner: MakeRoutes,
 {
     fn make_routes(&self) -> Routes {
-        let outer_rb = Service::make_routes(&self.outer);
-        let inner_rb = Service::make_routes(&self.inner);
+        let outer_rb = MakeRoutes::make_routes(&self.outer);
+        let inner_rb = MakeRoutes::make_routes(&self.inner);
         outer_rb.combine_with(inner_rb)
     }
 }
 
-/// Type that contains a [`Service`] and implements `tower::MakeService` to
+/// Type that contains a [`MakeRoutes`] and implements `tower::MakeService` to
 /// create [`RoutesFinalized`] instances.
-pub struct IntoMakeService<S: Service> {
+pub struct IntoMakeService<S: MakeRoutes> {
     mk_router: S,
 }
 
-impl<S: Service + Clone> Clone for IntoMakeService<S> {
+impl<S: MakeRoutes + Clone> Clone for IntoMakeService<S> {
     fn clone(&self) -> Self {
         Self {
             mk_router: self.mk_router.clone(),
@@ -194,7 +190,7 @@ impl<S: Service + Clone> Clone for IntoMakeService<S> {
     }
 }
 
-impl<T, S: Service> TowerService<T> for IntoMakeService<S> {
+impl<T, S: MakeRoutes> TowerService<T> for IntoMakeService<S> {
     type Response = RoutesFinalized;
 
     type Error = Infallible;
@@ -217,13 +213,13 @@ impl<T, S: Service> TowerService<T> for IntoMakeService<S> {
 mod tests {
     use tower::layer::util::Identity;
 
-    use crate::server::{router::Routes, HrpcLayer, Service};
+    use crate::server::{router::Routes, HrpcLayer, MakeRoutes};
 
     use super::utils::recommended_layers;
 
     struct TestServer;
 
-    impl Service for TestServer {
+    impl MakeRoutes for TestServer {
         fn make_routes(&self) -> Routes {
             Routes::new()
         }
@@ -234,9 +230,7 @@ mod tests {
         let s = TestServer;
 
         // we can't poll it, and we don't want to anyways
-        let _ = s
-            .layer(HrpcLayer::new(Identity::new()))
-            .serve("127.0.0.1:2289");
+        let _ = s.layer(HrpcLayer::new(Identity::new()));
     }
 
     #[test]
@@ -244,8 +238,6 @@ mod tests {
         let s = TestServer;
 
         // we can't poll it, and we don't want to anyways
-        let _ = s
-            .layer(recommended_layers(|_| true))
-            .serve("127.0.0.1:2289");
+        let _ = s.layer(recommended_layers(|_| true));
     }
 }
